@@ -1,5 +1,5 @@
 package Curio::Role::GitLab::API::v4;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use GitLab::API::v4;
 use Scalar::Util qw( blessed );
@@ -17,6 +17,7 @@ after initialize => sub{
     my $factory = $class->factory();
 
     $factory->does_caching( 1 );
+    $factory->resource_method_name( 'api' );
 
     return;
 };
@@ -24,7 +25,9 @@ after initialize => sub{
 has _custom_api => (
     is       => 'ro',
     isa      => InstanceOf[ 'GitLab::API::v4' ] | HashRef,
+    required => 1,
     init_arg => 'api',
+    clearer  => '_clear_custom_api',
 );
 
 has api => (
@@ -36,6 +39,7 @@ sub _build_api {
     my ($self) = @_;
 
     my $api = $self->_custom_api();
+    $self->_clear_custom_api();
     return $api if blessed $api;
 
     my $args = $api ? { %$api } : {};
@@ -75,8 +79,10 @@ Create your Curio class:
     use Curio role => '::GitLab::API::v4';
     use strictures 2;
     
-    export_function_name 'myapp_gitlab';
     key_argument 'connection_key';
+    export_function_name 'myapp_gitlab';
+    always_export;
+    export_resource;
     
     has connection_key => (
         is       => 'ro',
@@ -107,22 +113,23 @@ Create your Curio class:
 
 Then use your new Curio class elsewhere:
 
-    use MyApp::Service::GitLab qw( myapp_gitlab );
+    use MyApp::Service::GitLab;
     
     my $api = myapp_gitlab('admin');
 
 =head1 DESCRIPTION
 
-This role provides all the basics for building a Curio class which wraps around
-L<GitLab::API::v4>.
+This role provides all the basics for building a Curio class which
+wraps around L<GitLab::API::v4>.
 
-=head1 OPTIONAL ARGUMENTS
+=head1 REQUIRED ARGUMENTS
 
 =head2 api
 
 Holds the L<GitLab::API::v4> object.
 
-May be passed as a hashref of arguments, or a pre-created object.
+May be passed as either a hashref of arguments or a pre-created
+object.
 
 =head1 OPTIONAL METHODS
 
@@ -138,9 +145,10 @@ The L<GitLab::API::v4/private_token>.  See L</TOKENS>.
 
 =head1 TOKENS
 
-In your Curio class you may create two methods, L</access_token> and L</private_token>.
-If either/both of these methods exist and return a defined value then they will be used
-when constructing the L</api> object.
+In your Curio class you may create two methods, L</access_token> and
+L</private_token>.  If either/both of these methods exist and return a
+defined value then they will be used when constructing the L</api>
+object.
 
 In the L</SYNOPSIS> a sample C<private_token> method is shown:
 
@@ -152,23 +160,27 @@ In the L</SYNOPSIS> a sample C<private_token> method is shown:
         );
     }
 
-The C<myapp_secret> call is expected to be the place where you use whatever tool you use
-to hold your GitLab tokens and likely all passwords and other credentials (secrets) that
-your application needs.
+The C<myapp_secret> call is expected to be the place where you use
+whatever tool you use to hold your GitLab tokens and likely all
+passwords and other credentials (secrets) that your application needs.
 
-Some common tools that people use to manage their secrets are Kubernetes' secrets objects,
-AWS's Secret Manager, HashiCorp's Vault, or just an inescure configuration file; to name a
-few.
+Some common tools that people use to manage their secrets are
+Kubernetes' secrets objects, AWS's Secret Manager, HashiCorp's Vault,
+or just an inescure configuration file; to name a few.
 
-So, the way you write your token methods is going to be unique to your setup.
+So, the way you write your token methods is going to be unique to your
+setup.
 
 =head1 FEATURES
 
-This role sets the L<Curio::Factory/does_caching> feature.
+This role turns on L<Curio::Factory/does_caching> and sets
+L<Curio::Factory/resource_method_name> to C<api> (as in
+L</api>).
 
-You can of course disable this.
+You can of course revert these changes:
 
     does_caching 0;
+    resource_method_name undef;
 
 =head1 SUPPORT
 
@@ -179,9 +191,10 @@ L<https://github.com/bluefeet/Curio-Role-GitLab-API-v4/issues>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to L<ZipRecruiter|https://www.ziprecruiter.com/> for encouraging their employees
-to contribute back to the open source ecosystem.  Without their dedication to quality
-software development this distribution would not exist.
+Thanks to L<ZipRecruiter|https://www.ziprecruiter.com/> for
+encouraging their employees to contribute back to the open source
+ecosystem.  Without their dedication to quality software development
+this distribution would not exist.
 
 =head1 AUTHORS
 
@@ -191,16 +204,18 @@ software development this distribution would not exist.
 
 Copyright (C) 2019 Aran Clary Deltac
 
-This program is free software: you can redistribute it and/or modify it under the terms of
-the GNU General Public License as published by the Free Software Foundation, either
-version 3 of the License, or (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
-without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-See the GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License along with this program.
-If not, see L<http://www.gnu.org/licenses/>.
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
